@@ -1,9 +1,15 @@
-import simplejson
-import oauth2 as oauth
-from sys import maxint
-from urlparse import parse_qs
-from TwitterSearchException import TwitterSearchException
-from TwitterSearchOrder import TwitterSearchOrder
+import requests
+from requests_oauthlib import OAuth1
+from .TwitterSearchException import TwitterSearchException
+from .TwitterSearchOrder import TwitterSearchOrder
+from .utils import py3k
+
+try: from urllib.parse import parse_qs as parse # python3
+except ImportError: from urlparse import parse_qs as parse # python2
+
+# determine max int value
+try: from sys import maxint # python2
+except ImportError: from sys import maxsize as maxint # python3
 
 class TwitterSearch(object):
     base_url = 'https://api.twitter.com/1.1/'
@@ -27,7 +33,7 @@ class TwitterSearch(object):
                      504 : 'Gateway timeout: The request couldn\'t be serviced due to some failure within our stack',
                  }
 
-    def __init__(self, consumer_key, consumer_secret, access_token, access_token_secret, authenticate=True):
+    def __init__(self, consumer_key, consumer_secret, access_token, access_token_secret, verify=True):
         # app
         self.__consumer_key = consumer_key
         self.__consumer_secret = consumer_secret
@@ -44,22 +50,23 @@ class TwitterSearch(object):
         self._statistics = { 'queries' : 0, 'tweets' : 0 }
 
         # verify
-        if authenticate:
-            self.authenticate(True)
+        self.authenticate(verify)
 
     def isNextpage(self):
         if nextpage:
             return True
         return False
 
-    def authenticate(self, verify=False):
-        consumer = oauth.Consumer(key = self.__consumer_key, secret = self.__consumer_secret)
-        token = oauth.Token(key = self.__access_token, secret = self.__access_token_secret)
-        self.__client = oauth.Client(consumer, token)
+    def authenticate(self, verify=True):
+        self.__oauth = OAuth1(self.__consumer_key,
+            client_secret = self.__consumer_secret,
+            resource_owner_key = self.__access_token,
+            resource_owner_secret = self.__access_token_secret )
+        
 
         if verify:
-            meta, response = self.__client.request(self.base_url + self.verify_url, 'GET')
-            self.checkHTTPStatus(int(meta['status']))
+            r = requests.get(self.base_url + self.verify_url, auth=self.__oauth)
+            self.checkHTTPStatus(r.status_code)
 
     def checkHTTPStatus(self, http_status):
         if http_status in self.exceptions:
@@ -70,21 +77,26 @@ class TwitterSearch(object):
         return self
 
     def sentSearch(self, url):
-        if not isinstance(url, basestring):
-            raise TwitterSearchException(1009)
-        self._response['meta'], content = self.__client.request(self.base_url + self.search_url + url, 'GET')
+        if py3k:
+            if not isinstance(url, str):
+                raise TwitterSearchException(1009)
+        else:
+            if not isinstance(url, basestring):
+                raise TwitterSearchException(1009)
+        r = requests.get(self.base_url + self.search_url + url, auth=self.__oauth)
+        self._response['meta'] = r.headers
 
-        self.checkHTTPStatus(int(self._response['meta']['status']))
+        self.checkHTTPStatus(r.status_code)
 
         # using IDs to request more results - former versions used page parameter
         # see https://dev.twitter.com/docs/working-with-timelines
-        given_count = parse_qs(url)['count'][0]
-        self._response['content'] = simplejson.loads(content)
+        given_count = int(parse(url)['count'][0])
+        self._response['content'] = r.json()
 
         self._statistics['queries'] += 1
         self._statistics['tweets'] += len(self._response['content']['statuses'])
 
-        if self._response['content']['search_metadata']['count'] < given_count:
+        if int(self._response['content']['search_metadata']['count']) == given_count:
             # have a look for the lowest ID
             for tweet in self._response['content']['statuses']:
               if tweet['id'] < self._nextMaxID:
@@ -131,6 +143,9 @@ class TwitterSearch(object):
         return self
 
     def next(self):
+        return self.__next__()
+
+    def __next__(self):
         if self._nextTweet < len(self._response['content']['statuses']):
             self._nextTweet += 1
             return self._response['content']['statuses'][self._nextTweet-1]
